==> jain-sip-ri-1.2.85-sources.jar: gov/nist/javax/sdp/parser/KeyFieldParser.java <==
/*
* Conditions Of Use 
* 
* This software was developed by employees of the National Institute of
* Standards and Technology (NIST), an agency of the Federal Government.
* Pursuant to title 15 Untied States Code Section 105, works of NIST
* employees are not subject to copyright protection in the United States
* and are considered to be in the public domain.  As a result, a formal
* license is not needed to use the software.
* 
* This software is provided by NIST as a service and is expressly
* provided "AS IS."  NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTY OF
* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NON-INFRINGEMENT
* AND DATA ACCURACY.  NIST does not warrant or make any representations
* regarding the use of the software or the results thereof, including but
* not limited to the correctness, accuracy, reliability or usefulness of
* the software.
* 
* Permission to use this software is contingent upon your acceptance
* of the terms of this agreement
*  
* .
* 
*/
package gov.nist.javax.sdp.parser;

import gov.nist.javax.sdp.fields.*;
import gov.nist.core.*;
import java.text.*;

/**
 * Parser for key field. Ack: bug fix contributed by espen@java.net
 *
 * @author  deruelle
 * @version JAIN-SDP-PUBLIC-RELEASE $Revision: 1.6 $ $Date: 2007/10/22 03:38:26 $
 */
public class KeyFieldParser extends SDPParser {

	/** Creates new KeyFieldParser */
	public KeyFieldParser(String keyField) {
		this.lexer = new Lexer("charLexer", keyField);
	}

	public KeyField keyField() throws ParseException {
		try {
			this.lexer.match('k');
			this.lexer.SPorHT();
			this.lexer.match('=');
			this.lexer.SPorHT();

			KeyField keyField = new KeyField();
			//Espen: Stealing the approach from AttributeFieldParser from from here...
			NameValue nameValue = new NameValue();

			int ptr = this.lexer.markInputPosition();
			try {
				String name = lexer.getNextToken(':');
				this.lexer.consume(1);
				String value = lexer.getRest();
				nameValue = new NameValue(name.trim(), value.trim());
			} catch (ParseException ex) {
				this.lexer.rewindInputPosition(ptr);
				String rest = this.lexer.getRest();
				if (rest == null)
					throw new ParseException(
						this.lexer.getBuffer(),
						this.lexer.getPtr());
				nameValue = new NameValue(rest.trim(), null);
			}
			keyField.setType(nameValue.getName());
			keyField.setKeyData((String) nameValue.getValueAsObject());
			this.lexer.SPorHT();

			return keyField;
		} catch (Exception e) {
			throw new ParseException(lexer.getBuffer(), lexer.getPtr());
		}
	}

	public SDPField parse() throws ParseException {
		return this.keyField();
	}

	/**
	    public static void main(String[] args) throws ParseException {
		    String key[] = {
				"k=clear:1234124\n",
	                        "k=base64:12\n",
	                        "k=http://www.cs.ucl.ac.uk/staff/M.Handley/sdp.03.ps\n",
	                        "k=prompt\n"
	                };
	
		    for (int i = 0; i < key.length; i++) {
		       KeyFieldParser keyFieldParser=new KeyFieldParser(
	                key[i] );
			KeyField keyField=keyFieldParser.keyField();
			System.out.println("toParse: " +key[i]);
			System.out.println("encoded: " +keyField.encode());
		    }
	
		}
	**/
}
/*
 * $Log: KeyFieldParser.java,v $
 * Revision 1.6  2007/10/22 03:38:26  mranga
 * Issue number:
 * Obtained from:
 * Submitted by:  mranga
 * Reviewed by:   mranga
 *
 * Java 5 porting.
 *
 * Revision 1.5  2006/07/13 09:02:42  mranga
 * Issue number:
 * Obtained from:
 * Submitted by:  jeroen van bemmel
 * Reviewed by:   mranga
 * Moved some changes from jain-sip-1.2 to java.net
 *
 * CVS: ----------------------------------------------------------------------
 * CVS: Issue number:
 * CVS:   If this change addresses one or more issues,
 * CVS:   then enter the issue number(s) here.
 * CVS: Obtained from:
 * CVS:   If this change has been taken from another system,
 * CVS:   then name the system in this line, otherwise delete it.
 * CVS: Submitted by:
 * CVS:   If this code has been contributed to the project by someone else; i.e.,
 * CVS:   they sent us a patch or a set of diffs, then include their name/email
 * CVS:   address here. If this is your work then delete this line.
 * CVS: Reviewed by:
 * CVS:   If we are doing pre-commit code reviews and someone else has
 * CVS:   reviewed your changes, include their name(s) here.
 * CVS:   If you have not had it reviewed then delete this line.
 *
 * Revision 1.3  2006/06/19 06:47:26  mranga
 * javadoc fixups
 *
 * Revision 1.2  2006/06/16 15:26:28  mranga
 * Added NIST disclaimer to all public domain files. Clean up some javadoc. Fixed a leak
 *
 * Revision 1.1.1.1  2005/10/04 17:12:34  mranga
 *
 * Import
 *
 *
 * Revision 1.3  2004/01/22 13:26:28  sverker
 * Issue number:
 * Obtained from:
 * Submitted by:  sverker
 * Reviewed by:   mranga
 *
 * Major reformat of code to conform with style guide. Resolved compiler and javadoc warnings. Added CVS tags.
 *
 * CVS: ----------------------------------------------------------------------
 * CVS: Issue number:
 * CVS:   If this change addresses one or more issues,
 * CVS:   then enter the issue number(s) here.
 * CVS: Obtained from:
 * CVS:   If this change has been taken from another system,
 * CVS:   then name the system in this line, otherwise delete it.
 * CVS: Submitted by:
 * CVS:   If this code has been contributed to the project by someone else; i.e.,
 * CVS:   they sent us a patch or a set of diffs, then include their name/email
 * CVS:   address here. If this is your work then delete this line.
 * CVS: Reviewed by:
 * CVS:   If we are doing pre-commit code reviews and someone else has
 * CVS:   reviewed your changes, include their name(s) here.
 * CVS:   If you have not had it reviewed then delete this line.
 *
 */

==> jain-sip-ri-1.2.148.5-sources.jar: gov/nist/javax/sdp/parser/KeyFieldParser.java <==
/*
* Conditions Of Use
*
* This software was developed by employees of the National Institute of
* Standards and Technology (NIST), an agency of the Federal Government.
* Pursuant to title 15 Untied States Code Section 105, works of NIST
* employees are not subject to copyright protection in the United States
* and are considered to be in the public domain.  As a result, a formal
* license is not needed to use the software.
*
* This software is provided by NIST as a service and is expressly
* provided "AS IS."  NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTY OF
* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NON-INFRINGEMENT
* AND DATA ACCURACY.  NIST does not warrant or make any representations
* regarding the use of the software or the results thereof, including but
* not limited to the correctness, accuracy, reliability or usefulness of
* the software.
*
* Permission to use this software is contingent upon your acceptance
* of the terms of this agreement
*
* .
*
*/
package gov.nist.javax.sdp.parser;

import gov.nist.javax.sdp.fields.*;
import gov.nist.core.*;
import java.text.*;

/**
 * Parser for key field. Ack: bug fix contributed by espen@java.net
 *
 * @author  deruelle
 * @version JAIN-SDP-PUBLIC-RELEASE $Revision: 1.7 $ $Date: 2009/07/17 18:57:16 $
 */
public class KeyFieldParser extends SDPParser {

    /** Creates new KeyFieldParser */
    public KeyFieldParser(String keyField) {
        this.lexer = new Lexer("charLexer", keyField);
    }

    public KeyField keyField() throws ParseException {
        try {
            this.lexer.match('k');
            this.lexer.SPorHT();
            this.lexer.match('=');
            this.lexer.SPorHT();

            KeyField keyField = new KeyField();
            //Espen: Stealing the approach from AttributeFieldParser from from here...
            NameValue nameValue = new NameValue();

            int ptr = this.lexer.markInputPosition();
            try {
                String name = lexer.getNextToken(':');
                this.lexer.consume(1);
                String value = lexer.getRest();
                nameValue = new NameValue(name.trim(), value.trim());
            } catch (ParseException ex) {
                this.lexer.rewindInputPosition(ptr);
                String rest = this.lexer.getRest();
                if (rest == null)
                    throw new ParseException(
                        this.lexer.getBuffer(),
                        this.lexer.getPtr());
                nameValue = new NameValue(rest.trim(), null);
            }
            keyField.setType(nameValue.getName());
            keyField.setKeyData((String) nameValue.getValueAsObject());
            this.lexer.SPorHT();

            return keyField;
        } catch (Exception e) {
            throw new ParseException(lexer.getBuffer(), lexer.getPtr());
        }
    }

    public SDPField parse() throws ParseException {
        return this.keyField();
    }

    /**
        public static void main(String[] args) throws ParseException {
            String key[] = {
                "k=clear:1234124\n",
                            "k=base64:12\n",
                            "k=http://www.cs.ucl.ac.uk/staff/M.Handley/sdp.03.ps\n",
                            "k=prompt\n"
                    };

            for (int i = 0; i < key.length; i++) {
               KeyFieldParser keyFieldParser=new KeyFieldParser(
                    key[i] );
            KeyField keyField=keyFieldParser.keyField();
            System.out.println("toParse: " +key[i]);
            System.out.println("encoded: " +keyField.encode());
            }

        }
    **/
}
/*
 * $Log: KeyFieldParser.java,v $
 * Revision 1.7  2009/07/17 18:57:16  emcho
 * Converts indentation tabs to spaces so that we have a uniform indentation policy in the whole project.
 *
 * Revision 1.6  2007/10/22 03:38:26  mranga
 * Issue number:
 * Obtained from:
 * Submitted by:  mranga
 * Reviewed by:   mranga
 *
 * Java 5 porting.
 *
 * Revision 1.5  2006/07/13 09:02:42  mranga
 * Issue number:
 * Obtained from:
 * Submitted by:  jeroen van bemmel
 * Reviewed by:   mranga
 * Moved some changes from jain-sip-1.2 to java.net
 *
 * CVS: ----------------------------------------------------------------------
 * CVS: Issue number:
 * CVS:   If this change addresses one or more issues,
 * CVS:   then enter the issue number(s) here.
 * CVS: Obtained from:
 * CVS:   If this change has been taken from another system,
 * CVS:   then name the system in this line, otherwise delete it.
 * CVS: Submitted by:
 * CVS:   If this code has been contributed to the project by someone else; i.e.,
 * CVS:   they sent us a patch or a set of diffs, then include their name/email
 * CVS:   address here. If this is your work then delete this line.
 * CVS: Reviewed by:
 * CVS:   If we are doing pre-commit code reviews and someone else has
 * CVS:   reviewed your changes, include their name(s) here.
 * CVS:   If you have not had it reviewed then delete this line.
 *
 * Revision 1.3  2006/06/19 06:47:26  mranga
 * javadoc fixups
 *
 * Revision 1.2  2006/06/16 15:26:28  mranga
 * Added NIST disclaimer to all public domain files. Clean up some javadoc. Fixed a leak
 *
 * Revision 1.1.1.1  2005/10/04 17:12:34  mranga
 *
 * Import
 *
 *
 * Revision 1.3  2004/01/22 13:26:28  sverker
 * Issue number:
 * Obtained from:
 * Submitted by:  sverker
 * Reviewed by:   mranga
 *
 * Major reformat of code to conform with style guide. Resolved compiler and javadoc warnings. Added CVS tags.
 *
 * CVS: ----------------------------------------------------------------------
 * CVS: Issue number:
 * CVS:   If this change addresses one or more issues,
 * CVS:   then enter the issue number(s) here.
 * CVS: Obtained from:
 * CVS:   If this change has been taken from another system,
 * CVS:   then name the system in this line, otherwise delete it.
 * CVS: Submitted by:
 * CVS:   If this code has been contributed to the project by someone else; i.e.,
 * CVS:   they sent us a patch or a set of diffs, then include their name/email
 * CVS:   address here. If this is your work then delete this line.
 * CVS: Reviewed by:
 * CVS:   If we are doing pre-commit code reviews and someone else has
 * CVS:   reviewed your changes, include their name(s) here.
 * CVS:   If you have not had it reviewed then delete this line.
 *
 */
